==> moodle-1.4.5.tgz: moodle/lang/et/exercise.php <==
<?PHP // $Id: exercise.php,v 1.1.6.2 2004/12/17 16:02:03 moodler Exp $ 
      // exercise.php - created with Moodle 1.3.3 + (2004052503)


$string['absent'] = 'Puuduv';
$string['accumulative'] = 'Kogunev';
$string['action'] = 'Tegevus';
$string['ago'] = '$ tagasi';
$string['allgradeshaveamaximumof'] = 'Kik hinded on maksimaalselt: $a';
$string['amend'] = 'Paranda';
$string['amendassessmentelements'] = 'Paranda hindamise elemente';
$string['amendtitle'] = 'Paranda pealkiri';
$string['assess'] = 'Hinda';
$string['assessed'] = 'Hinnatud';
$string['assessment'] = 'Hindamine';
$string['assessmentby'] = 'Hinnatud $a poolt';
$string['assessmentform'] = 'Hindamise vorm';
$string['assessmentmadebythe'] = 'Hindamise teostas $a';
$string['assessmentofthissubmission'] = 'Esitise hindamine';
$string['assessments'] = 'Hindamised';
$string['atthisstageyou'] = 'Oled praeguseks lpetanud hindamise.<br />Vid oma t selle hinnangu phjal le vaadata.<br />Seda tehes paranda hiljem ka oma hinnangut.<br />Vid teha seda vajutades allpool toodud Uuesti hindamise linki.';
$string['awaitingassessmentbythe'] = 'Ootab hindamist $a poolt';
$string['awaitingfeedbackfromthe'] = 'Ootab tagasisidet $a poolt';
$string['clearlateflag'] = 'Kustuta hilinemise mrge';
$string['comment'] = 'Kommentaar';
$string['confirmdeletionofthisitem'] = 'Kinnita $a kustutamine';
$string['correct'] = 'Paranda';
$string['criterion'] = 'Kriteerium';
$string['deadline'] = 'Thtaeg';
$string['deadlineis'] = 'Thtaeg on $a';
$string['delete'] = 'Kustuta';
$string['deleting'] = 'Kustutan';
$string['description'] = 'Kirjeldus';
$string['descriptionofexercise'] = 'Harjutuse lesandes pannakse $a poolt tehtav t HTML vi Wordi dokumenti. See fail laetakse harjutusse enne $a poolt avamist. Samuti on vimalik luua variantide kogum sama harjutuse vi t kohta, jllegi HTML vi Wordi dokumendina ja laadida see enne $a poolt avamist harjutusse.';
$string['detailsofassessment'] = 'lesande detailid';
$string['displayoffinalgrades'] = 'Lpphinnete nitamine';
$string['doubleupload'] = 'Hoiatus: see esitus on arvatavasti saadetud kaks korda. Mine administreerimise lehele ja otsi lhikese ajavahemiku jooksul postitatud sama kasutaja esitust. Enne jtkamist kustuta ks neist';
$string['duedate'] = 'Thtaeg';
$string['edit'] = 'Muuda';
$string['editingassessmentelements'] = 'Muuda hindamise elemente';
$string['element'] = 'Element';
$string['elementweight'] = 'Elemendi osakaal';
$string['entriessaved'] = 'Salvestatud kirjeid';
$string['errorbanded'] = 'Viga mrgistatud';
$string['excellent'] = 'Vga hea';
$string['exerciseassessments'] = 'Harjutuse hinnangud';
$string['exercisefeedback'] = 'Harjutuse tagasiside';
$string['exercisesubmissions'] = 'Harjutuse esitis';
$string['generalcomment'] = 'ldine kommentaar';
$string['good'] = 'Hea';
$string['gradeassessment'] = 'Hinde hinnang';
$string['gradeforassessment'] = 'Hinnangu hinne';
$string['gradeforstudentsassessment'] = '$a hinnangu hinne';
$string['gradeforsubmission'] = 'Esituse hinne';
$string['gradetable'] = 'Hinnete tabel';
$string['gradingstrategy'] = 'Hindamise strateegia';
$string['handlingofmultiplesubmissions'] = 'Mitmete esitiste ttlemine';
$string['hidenamesfromstudents'] = 'Peida nimed pilaste eest';
$string['incorrect'] = 'Vale';
$string['leaguetable'] = 'Liiga Tabel esitatud tdest';
$string['mail1'] = 'Sinu lesannet \'$a\' hindas';
$string['mail2'] = 'Kommentaarid ja hinne on nhtav \'$a\' Harjutuse lesandes';
$string['mail3'] = 'Vid nha seda oma Harjutuse lesandes';
$string['mail6'] = 'Sinu hinnang lesandele \'$a\' on le vaadatud';
$string['mail7'] = 'Kommentaarid $a poolt on nhtavad Harjutuse lesandes';
$string['managingassignment'] = 'Harjutuse haldamine';
$string['maximumsize'] = 'Maksimumsuurus';
$string['modulename'] = 'Harjutus';
$string['modulenameplural'] = 'Harjutused';
$string['movingtophase'] = 'Liigun faasi $a';
$string['multiplesubmissions'] = 'Mitu esitust';
$string['noexercisedescriptionssubmitted'] = 'Harjutuse kirjeldusi pole esitatud';
$string['nosubmissions'] = 'Esitused puuduvad';
$string['notassessedyet'] = 'Ei ole veel hinnatud';
$string['notavailable'] = 'Ei ole saadaval';
$string['noteonassessmentelements'] = 'Vta teadmiseks, et hindamine on jaotatud mitmeks \'Hindamise elemendiks\'<br />See muudab hindamise lihtsamaks ja jrjepidevamaks. petajana pead lisama need elemendid enne harjutuse avalikuks tegemist<br />Seda saab teha vajutades kursuse lesandele, kui htegi elementi ei ole loodud, palutakse sul need lisada.<br />Sa vid elementide arvu muuta kasutades Muude lesannet lehte,<br />elemendid ise on lisatavad lesande Haldamise lehelt.';
$string['noteonstudentassessments'] = '{Hinne pilaselt / Hinnangu hinne petajalt}';
$string['notgraded'] = 'Ei ole hinnatud';
$string['notitlegiven'] = 'Pealkirja pole';
$string['nowpleasemakeyourownassessment'] = 'Nd palun tee oma enda hinnang tle $a poolt.<br />Pane thele, et hindamise vormi pannakse algul samad hinded, mis pilase vormi. Peaksid tegema kik muudatused mida vajalikuks pead ja siis vajutama lehe jaluses olevat nuppu';
$string['numberofassessmentelements'] = 'Kommentaaride, Hindamise elementide, Hinnete mrgistuste, Kriteeriumite vi Kategooriate arv rubriigis';
$string['numberofentries'] = 'Kirjete arv';
$string['numberofnegativeresponses'] = 'Negatiivsete vastuste arv';
$string['onesubmission'] = 'ks esitus';
$string['optionaladjustment'] = 'Valikuline muutmine';
$string['overallgrade'] = 'ldhinne';
$string['phase'] = 'Faas';
$string['phase1'] = 'Seadista lesanne';
$string['phase1short'] = 'Seadista';
$string['phase2'] = 'Luba $a Hinnangud ja Esitused';
$string['phase2short'] = 'Ava';
$string['phase3'] = 'Nita ldhindeid ja liiga tabelit';
$string['phase3short'] = 'Kuva';
$string['pleasegradetheassessment'] = 'Palun hinda $a poolt tehtud t hinnangut';
$string['pleasesubmityourwork'] = 'Palun sisesta oma t kasutades seda vormi';
$string['pleaseusethisform'] = 'Palun tida see vorm kui oled lpetanud harjutuses toodud lesanded.';
$string['pleaseviewtheexercise'] = 'Palun vaata allpool toodud harjutust vajutades selle pealkirjale.<br />Peaksid jlgima toodud juhiseid<br />Kui oled tulemusega rahul vajuta Hinda (vi hinda uuesti) linki allpool toodud kastis.<br />Kui oled selle hinnangu lpetanud nidatakse sulle juhendit edasiseks tegevuseks';
$string['poor'] = 'Vilets';
$string['present'] = 'Olemas';
$string['reasonforadjustment'] = 'Muutmise phjus';
$string['reassess'] = 'Hinda uuesti';
$string['resubmissionfor'] = '$a uuesti esitamine';
$string['resubmitnote'] = '* thendab, et $a on lubatud seda esitust uuesti teha. <br /> Selle vimaluse vib anda igale esitusele hinnates seda uuesti ja vajutades <b>Luba $a uuesti esitada</b>nuppu.<br />pilane saab uuesti esitada, kui see on lubatud vhemalt <b>hel</b> tema esitustest';
$string['rubric'] = 'Rubriik';
$string['savedok'] = 'Salvestus OK';
$string['saveentries'] = 'Salvesta kirjed';
$string['savemyassessment'] = 'Salvesta minu hinnang';
$string['saveweights'] = 'Salvesta kaalukus';
$string['scale10'] = 'Skoor 10st';
$string['scale100'] = 'Skoor 100st';
$string['scale20'] = 'Skoor 20st';
$string['scalecorrect'] = '2 punkti ige/Vale skaala';
$string['scaleexcellent4'] = '4 punkti Vga hea/Vga halb skaala';
$string['scaleexcellent5'] = '5 punkti Vga hea/Vga halb skaala';
$string['scaleexcellent7'] = '7 punkti Vga hea/Vga halb skaala';
$string['scalegood3'] = '3 punkti Hea/Halb skaala';
$string['scalepresent'] = '2 punkti Olemas/Puudub skaala';
$string['scaleyes'] = '2 punkti Jah/Ei skaala';
$string['specimenassessmentform'] = 'Elemendi hindamise vorm';
$string['studentallowedtoresubmit'] = '$a on LUBATUD uuesti esitada';
$string['studentassessments'] = '$a hinnangud';
$string['studentnotallowed'] = '$a ei ole lubatud uuesti sisestada (vi ei ole vaja)';
$string['studentsubmissions'] = '$a esitused';
$string['studentsubmissionsforassessment'] = '$a pilase esitused hindamiseks';
$string['submission'] = 'Esitus';
$string['submissions'] = 'Esitused';
$string['submissionsnowclosed'] = 'Esituste thtaeg on mdas - uusi esitusi enam vastu ei veta';
$string['submitexercisedescription'] = 'Sisesta harjutuse kirjeldus';
$string['submitted'] = 'Esitatud';
$string['submittedby'] = 'Esitas';
$string['suggestedgrade'] = 'Soovitatud hinne';
$string['teacherassessment'] = '$a hinnang';
$string['teacherassessmenttable'] = '$a hinnangu tabel';
$string['teacherscomment'] = 'petaja kommentaar';
$string['theexercise'] = 'lesanne';
$string['theexerciseandthesubmissionby'] = 'lesanne ja esitus $a poolt';
$string['thegradeis'] = 'Hinne on $a';
$string['thereisfeedbackfromthe'] = 'On tagasisidet $a poolt';
$string['thisisaresubmission'] = 'See on Uuesti esitamine $a poolt.<br />Kuvatud on sinu hinnang eelmisele esitusele. <br />Peale uue esituse vaatamist, lisa see hinnangusse <br /> ja vajuta nuppu.';
$string['title'] = 'Pealkiri';
$string['typeofscale'] = 'Skaala tp';
$string['ungradedstudentassessments'] = '$a hindamata pilaste hinnanguid';
$string['usemaximum'] = 'Kasuta maksimumi';
$string['usemean'] = 'Kasuta keskmist';
$string['verypoor'] = 'Vga halb';
$string['view'] = 'Vaata';
$string['viewassessment'] = 'Vaata hinnangut';
$string['warningonamendingelements'] = 'HOIATUS: On esitatud hinnangud. <br /> RA muuda elementide arvu, skaalade tpi vi elementide kaalukust.';
$string['weightederrorcount'] = 'Kaalutud vigade arv: $a';
$string['weightforgradingofassessments'] = 'Hindamise hinnete kaalukus';
$string['weightforteacherassessments'] = '$a hinnangute kaalukus';
$string['weights'] = 'Kaalukus';
$string['weightssaved'] = 'Kaalukus salvestatud';
$string['weightsusedforoverallgrade'] = 'Kaalukust kasutatakse ldhindes';
$string['yourassessment'] = 'Sinu hinnang';
$string['yourfeedbackgoeshere'] = 'Sinu tagasiside lheb siia';
$string['yoursubmission'] = 'Sinu esitus';

?>

==> moodle-1.5.3.tgz: moodle/lang/et/exercise.php <==
<?PHP // $Id$ 
      // exercise.php - created with Moodle 1.4.4 + (2004083140)


$string['absent'] = 'Puuduv';
$string['accumulative'] = 'Kogunev';
$string['action'] = 'Tegevus';
$string['ago'] = '$ tagasi';
$string['amend'] = 'Paranda';
$string['amendassessmentelements'] = 'Paranda hindamise elemente';
$string['amendtitle'] = 'Paranda pealkiri';
$string['analysis'] = 'anals';
$string['assess'] = 'Hinda';
$string['assessed'] = 'Hinnatud';
$string['assessment'] = 'Hindamine';
$string['assessmentby'] = 'Hinnatud $a poolt';
$string['assessmentform'] = 'Hindamise vorm';
$string['assessmentmadebythe'] = 'Hindamise teostas $a';
$string['assessmentofthissubmission'] = 'Esitise hindamine';
$string['assessments'] = 'Hindamised';
$string['atthisstageyou'] = 'Oled praeguseks lpetanud hindamise.<br />Vid oma t selle hinnangu phjal le vaadata.<br />Seda tehes paranda hiljem ka oma hinnangut.<br />Vid teha seda vajutades allpool toodud Uuesti hindamise linki.';
$string['awaitingassessmentbythe'] = 'Ootab hindamist $a poolt';
$string['clearlateflag'] = 'Kustuta hilinemise mrge';
$string['comment'] = 'Kommentaar';
$string['comparisonofassessments'] = 'Vrtuste vrdlemine';
$string['confirmdeletionofthisitem'] = 'Kinnita $a kustutamine';
$string['correct'] = 'Paranda';
$string['count'] = 'ldarv';
$string['criterion'] = 'Kriteerium';
$string['deadline'] = 'Thtaeg';
$string['deadlineis'] = 'Thtaeg on $a';
$string['delete'] = 'Kustuta';
$string['deletesubmissionwarning'] = 'Hoiatus: $a vrtus seostub koos selle kaastga.<br /> On tungivalt soovitatav ,et seda kaastd EI kustutataks';
$string['deleting'] = 'Kustutan';
$string['description'] = 'Kirjeldus';
$string['descriptionofexercise'] = 'Harjutuse lesandes pannakse $a poolt tehtav t HTML vi Wordi dokumenti. See fail laetakse harjutusse enne $a poolt avamist. Samuti on vimalik luua variantide kogum sama harjutuse vi t kohta, jllegi HTML vi Wordi dokumendina ja laadida see enne $a poolt avamist harjutusse.';
$string['detailsofassessment'] = 'lesande detailid';
$string['displayoffinalgrades'] = 'Lpphinnete nitamine';
$string['doubleupload'] = 'Hoiatus: see esitus on arvatavasti saadetud kaks korda. Mine administreerimise lehele ja otsi lhikese ajavahemiku jooksul postitatud sama kasutaja esitust. Enne jtkamist kustuta ks neist';
$string['duedate'] = 'Thtaeg';
$string['edit'] = 'Muuda';
$string['editingassessmentelements'] = 'Muuda hindamise elemente';
$string['element'] = 'Element';
$string['elementweight'] = 'Elemendi osakaal';
$string['enterpassword'] = 'Sisesta parool';
$string['entriessaved'] = 'Salvestatud kirjeid';
$string['errorbanded'] = 'Viga mrgistatud';
$string['excellent'] = 'Vga hea';
$string['exerciseassessments'] = 'Harjutuse hinnangud';
$string['exercisefeedback'] = 'Harjutuse tagasiside';
$string['exercisesubmissions'] = 'Harjutuse esitis';
$string['fair'] = 'iglane';
$string['generalcomment'] = 'ldine kommentaar';
$string['good'] = 'Hea';
$string['gradeassessment'] = 'Hinde hinnang';
$string['gradeforassessment'] = 'Hinnangu hinne';
$string['gradeforstudentsassessment'] = '$a hinnangu hinne';
$string['gradeforsubmission'] = 'Esituse hinne';
$string['gradetable'] = 'Hinnete tabel';
$string['gradinggrade'] = 'Hindav hinne';
$string['gradingstrategy'] = 'Hindamise strateegia';
$string['handlingofmultiplesubmissions'] = 'Mitmete esitiste ttlemine';
$string['hidenamesfromstudents'] = 'Peida nimed pilaste eest';
$string['incorrect'] = 'Vale';
$string['late'] = 'Hiline';
$string['lax'] = 'Ltv';
$string['leaguetable'] = 'Liiga Tabel esitatud tdest';
$string['mail1'] = 'Sinu lesannet \'$a\' hindas';
$string['mail2'] = 'Kommentaarid ja hinne on nhtav \'$a\' Harjutuse lesandes';
$string['mail3'] = 'Vid nha seda oma Harjutuse lesandes';
$string['mail6'] = 'Sinu hinnang lesandele \'$a\' on le vaadatud';
$string['mail7'] = 'Kommentaarid $a poolt on nhtavad Harjutuse lesandes';
$string['managingassignment'] = 'Harjutuse haldamine';
$string['maximum'] = 'Maksimum';
$string['maximumgradeforstudentassessments'] = 'Maksimum hinne pilase vrtusele: $a';
$string['maximumgradeforsubmissions'] = 'Maksimum hinne kaast eest : $a';
$string['maximumsize'] = 'Maksimumsuurus';
$string['mean'] = 'Keskmine';
$string['minimum'] = 'Miinimum';
$string['modulename'] = 'Harjutus';
$string['modulenameplural'] = 'Harjutused';
$string['movingtophase'] = 'Liigun faasi $a';
$string['multiplesubmissions'] = 'Mitu esitust';
$string['noexercisedescriptionssubmitted'] = 'Harjutuse kirjeldusi pole esitatud';
$string['nosubmissions'] = 'Esitused puuduvad';
$string['notassessedyet'] = 'Ei ole veel hinnatud';
$string['notavailable'] = 'Ei ole saadaval';
$string['noteonassessmentelements'] = 'Vta teadmiseks, et hindamine on jaotatud mitmeks \'Hindamise elemendiks\'<br />See muudab hindamise lihtsamaks ja jrjepidevamaks. petajana pead lisama need elemendid enne harjutuse avalikuks tegemist<br />Seda saab teha vajutades kursuse lesandele, kui htegi elementi ei ole loodud, palutakse sul need lisada.<br />Sa vid elementide arvu muuta kasutades Muude lesannet lehte,<br />elemendid ise on lisatavad lesande Haldamise lehelt.';
$string['noteongradinggrade'] = 'See hinne mdab sinu hinnangut $a-ga hinnanguga kes  on le vaadanud sinu t. Mida krgem hinne seda lhemal on hilduvus';
$string['noteonstudentassessments'] = '{Hinne pilaselt / Hinnangu hinne petajalt}';
$string['notgraded'] = 'Ei ole hinnatud';
$string['notitlegiven'] = 'Pealkirja pole';
$string['numberofassessmentelements'] = 'Kommentaaride, Hindamise elementide, Hinnete mrgistuste, Kriteeriumite vi Kategooriate arv rubriigis';
$string['numberofcriterionelements'] = 'Elementide kriteeria number peab olema suurem kui ks';
$string['numberofentries'] = 'Kirjete arv';
$string['numberofentriesinleaguetable'] = 'Liiga tabeli sisestuste number';
$string['numberofnegativeresponses'] = 'Negatiivsete vastuste arv';
$string['onesubmission'] = 'ks esitus';
$string['optionaladjustment'] = 'Valikuline muutmine';
$string['overallgrade'] = 'ldhinne';
$string['passwordprotectedexercise'] = 'Parooli kaitsev harjutus';
$string['phase'] = 'Faas';
$string['phase1'] = 'Seadista lesanne';
$string['phase1short'] = 'Seadista';
$string['phase2'] = 'Luba $a Hinnangud ja Esitused';
$string['phase2short'] = 'Ava';
$string['phase3'] = 'Nita ldhindeid ja liiga tabelit';
$string['phase3short'] = 'Kuva';
$string['pleasegradetheassessment'] = 'Palun hinda $a poolt tehtud t hinnangut';
$string['pleasemakeyourownassessment'] = 'Palun tehke oma hinnang $a poolt tehtud t kohta
<br /> Mrge: Hinnang sellest kuvatakse koos pilaste hinnangutega.<br /> Sa peaksid tegema kik vajalikud parandused mida vajalikuks pead ja siis klikkima hele <br /> jaluses asetsevatele nuppudele';
$string['pleasesubmityourwork'] = 'Palun sisesta oma t kasutades seda vormi';
$string['pleaseusethisform'] = 'Palun tida see vorm kui oled lpetanud harjutuses toodud lesanded.';
$string['pleaseviewtheexercise'] = 'Palun vaata allpool toodud harjutust vajutades selle pealkirjale.<br />Peaksid jlgima toodud juhiseid<br />Kui oled tulemusega rahul vajuta Hinda (vi hinda uuesti) linki allpool toodud kastis.<br />Kui oled selle hinnangu lpetanud nidatakse sulle juhendit edasiseks tegevuseks';
$string['poor'] = 'Vilets';
$string['present'] = 'Olemas';
$string['reasonforadjustment'] = 'Muutmise phjus';
$string['reassess'] = 'Hinda uuesti';
$string['regradestudentassessments'] = 'Hinda mber pilaste hinnanguid';
$string['resubmissionfor'] = '$a uuesti esitamine';
$string['resubmitnote'] = '* thendab, et $a on lubatud seda esitust uuesti teha. <br /> Selle vimaluse vib anda igale esitusele hinnates seda uuesti ja vajutades <b>Luba $a uuesti esitada</b>nuppu.<br />pilane saab uuesti esitada, kui see on lubatud vhemalt <b>hel</b> tema esitustest';
$string['rubric'] = 'Rubriik';
$string['savedok'] = 'Salvestus OK';
$string['saveentries'] = 'Salvesta kirjed';
$string['savemyassessment'] = 'Salvesta minu hinnang';
$string['saveweights'] = 'Salvesta kaalukus';
$string['scale10'] = 'Skoor 10st';
$string['scale100'] = 'Skoor 100st';
$string['scale20'] = 'Skoor 20st';
$string['scalecorrect'] = '2 punkti ige/Vale skaala';
$string['scaleexcellent4'] = '4 punkti Vga hea/Vga halb skaala';
$string['scaleexcellent5'] = '5 punkti Vga hea/Vga halb skaala';
$string['scaleexcellent7'] = '7 punkti Vga hea/Vga halb skaala';
$string['scalegood3'] = '3 punkti Hea/Halb skaala';
$string['scalepresent'] = '2 punkti Olemas/Puudub skaala';
$string['scaleyes'] = '2 punkti Jah/Ei skaala';
$string['specimenassessmentform'] = 'Elemendi hindamise vorm';
$string['standarddeviation'] = 'Keskmine elemendi $a krvalekalle:';
$string['strict'] = 'range';
$string['studentallowedtoresubmit'] = '$a on LUBATUD uuesti esitada';
$string['studentassessments'] = '$a hinnangud';
$string['studentnotallowed'] = '$a ei ole lubatud uuesti sisestada (vi ei ole vaja)';
$string['studentsubmissions'] = '$a esitused';
$string['studentsubmissionsforassessment'] = '$a pilase esitused hindamiseks';
$string['submission'] = 'Esitus';
$string['submissions'] = 'Esitused';
$string['submissionsnowclosed'] = 'Esituste thtaeg on mdas - uusi esitusi enam vastu ei veta';
$string['submitexercisedescription'] = 'Sisesta harjutuse kirjeldus';
$string['submitted'] = 'Esitatud';
$string['submittedby'] = 'Esitas';
$string['suggestedgrade'] = 'Soovitatud hinne';
$string['teacherassessment'] = '$a hinnang';
$string['teacherassessmenttable'] = '$a hinnangu tabel';
$string['teacherscomment'] = 'petaja kommentaar';
$string['theexercise'] = 'lesanne';
$string['theexerciseandthesubmissionby'] = 'lesanne ja esitus $a poolt';
$string['thegradeis'] = 'Hinne on $a';
$string['thereisfeedbackfromthe'] = 'On tagasisidet $a poolt';
$string['thisisaresubmission'] = 'See on Uuesti esitamine $a poolt.<br />Kuvatud on sinu hinnang eelmisele esitusele. <br />Peale uue esituse vaatamist, lisa see hinnangusse <br /> ja vajuta nuppu.';
$string['title'] = 'Pealkiri';
$string['typeofscale'] = 'Skaala tp';
$string['unassessed'] = '$a le vaatamata';
$string['ungradedstudentassessments'] = '$a hindamata pilaste hinnanguid';
$string['usemaximum'] = 'Kasuta maksimumi';
$string['usemean'] = 'Kasuta keskmist';
$string['usepassword'] = 'Kasuta parooli';
$string['verylax'] = 'Vga ltv';
$string['verypoor'] = 'Vga halb';
$string['verystrict'] = 'Vga range';
$string['view'] = 'Vaata';
$string['viewteacherassessment'] = 'Vaata $a hinnanguid';
$string['warningonamendingelements'] = 'HOIATUS: On esitatud hinnangud. <br /> RA muuda elementide arvu, skaalade tpi vi elementide kaalukust.';
$string['weightederrorcount'] = 'Kaalutud vigade arv: $a';
$string['weightforgradingofassessments'] = 'Hindamise hinnete kaalukus';
$string['weightforteacherassessments'] = '$a hinnangute kaalukus';
$string['weights'] = 'Kaalukus';
$string['weightssaved'] = 'Kaalukus salvestatud';
$string['weightsusedforoverallgrade'] = 'Kaalukust kasutatakse ldhindes';
$string['wrongpassword'] = 'Vale salasna selle kasutajanime juures';
$string['yourassessment'] = 'Sinu hinnang';
$string['yourfeedbackgoeshere'] = 'Sinu tagasiside lheb siia';
$string['yoursubmission'] = 'Sinu esitus';

?>
